<?php

namespace Drupal\commerce_stock_notifications\Controller;

use Drupal\commerce_stock_notifications\Entity\StockNotification;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class StockNotificationController.
 *
 * @package Drupal\commerce_stock_notifications\Controller
 */
class StockNotificationController extends ControllerBase {

  /**
   * Unsubscribe the user from the notification.
   *
   * @param string $user
   *   User ID.
   * @param string $notification_id
   *   Notification ID.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   Redirect.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function unsubscribe(string $user, string $notification_id) {
    $notification = StockNotification::load($notification_id);
    if ($notification === NULL) {
      return new RedirectResponse('/system/404');
    }
    if (!in_array('administrator', \Drupal::currentUser()->getRoles())) {
      if (\Drupal::currentUser()->isAnonymous() ||
          \Drupal::currentUser()->id() != $user) {
        return new RedirectResponse('/system/403');
      }
      else {
        if ($notification->getOwner()->id() != $user) {
          return new RedirectResponse('/system/403');
        }
      }
    }
    $notification->delete();
    \Drupal::messenger()->addStatus($this->t('Successfully unsubscribed.'));
    return new RedirectResponse('/');
  }

}
