<?php

namespace Drupal\commerce_stock_notifications\Plugin\QueueWorker;

use Drupal\commerce_product\Entity\ProductVariation;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Queue\QueueWorkerBase;

/**
 * Sends out notifications when items are in stock.
 *
 * @QueueWorker(
 *   id = "commerce_stock_notifications",
 *   title = @Translation("Commerce Stock Notification Queue"),
 *   cron = {"time" = 120}
 * )
 */
class CommerceStockNotifyQueue extends QueueWorkerBase {

  /**
   * Mail service for sending out the mail.
   *
   * @var mixed
   */
  private $mailManager;

  /**
   * CommerceStockNotifyQueue constructor.
   *
   * @param array $configuration
   *   Configuration.
   * @param mixed $plugin_id
   *   Plugin ID.
   * @param mixed $plugin_definition
   *   Plugin Definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);

    $this->mailManager = \Drupal::service('plugin.manager.mail');
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($data) {

    if (empty($data->get('sent_time')->getValue())) {
      $user = user_load_by_mail($data->getEmail());
      $product = ProductVariation::load($data->get('product_id')->getString());
      if (!$product->isPublished() || !$product->getProduct()->isPublished()) {
        // Product is inactive, ignore it.
        throw new \Exception("Product '" . $product->getSku() . "'(or it's parent product) is inactive. Skipping for now.");
      }
      // Parameters.
      $params = [
        'mail_title' => '"' . $product->getTitle() . '" is now in stock!',
        'message' => 'Hello, ' . $user->getDisplayName() . '. We just want to notify you that the item "' . $product->getTitle() . '" is now in stock!',
      ];
      // Send a message.
      $this->mailManager->mail('commerce_stock_notifications', 'notify', $data->getEmail(), $user->getPreferredLangcode(), $params, NULL, TRUE);

      $time = new DrupalDateTime();

      $data->set('sent_time', $time->getTimestamp())->save();
    }

  }

}
